CapacityProvider class

The details of a capacity provider.

Constructors

CapacityProvider({AutoScalingGroupProvider? autoScalingGroupProvider, String? capacityProviderArn, String? name, CapacityProviderStatus? status, List<Tag>? tags, CapacityProviderUpdateStatus? updateStatus, String? updateStatusReason})
CapacityProvider.fromJson(Map<String, dynamic> json)
factory

Properties

autoScalingGroupProvider → AutoScalingGroupProvider?
The Auto Scaling group settings for the capacity provider.
final
capacityProviderArn → String?
The Amazon Resource Name (ARN) that identifies the capacity provider.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the capacity provider.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → CapacityProviderStatus?
The current status of the capacity provider. Only capacity providers in an ACTIVE state can be used in a cluster. When a capacity provider is successfully deleted, it will have an INACTIVE status.
final
tags → List<Tag>?
The metadata that you apply to the capacity provider to help you categorize and organize it. Each tag consists of a key and an optional value, both of which you define.
final
updateStatus → CapacityProviderUpdateStatus?
The update status of the capacity provider. The following are the possible states that will be returned.
final
updateStatusReason → String?
The update status reason. This provides further details about the update status for the capacity provider.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited