Container class

A Docker container that is part of a task.

Constructors

Container({String? containerArn, String? cpu, int? exitCode, List<String>? gpuIds, HealthStatus? healthStatus, String? image, String? imageDigest, String? lastStatus, String? memory, String? memoryReservation, String? name, List<NetworkBinding>? networkBindings, List<NetworkInterface>? networkInterfaces, String? reason, String? runtimeId, String? taskArn})
Container.fromJson(Map<String, dynamic> json)
factory

Properties

containerArn → String?
The Amazon Resource Name (ARN) of the container.
final
cpu → String?
The number of CPU units set for the container. The value will be 0 if no value was specified in the container definition when the task definition was registered.
final
exitCode → int?
The exit code returned from the container.
final
gpuIds → List<String>?
The IDs of each GPU assigned to the container.
final
hashCode → int
The hash code for this object.
no setterinherited
healthStatus → HealthStatus?
The health status of the container. If health checks are not configured for this container in its task definition, then it reports the health status as UNKNOWN.
final
image → String?
The image used for the container.
final
imageDigest → String?
The container image manifest digest.
final
lastStatus → String?
The last known status of the container.
final
memory → String?
The hard limit (in MiB) of memory set for the container.
final
memoryReservation → String?
The soft limit (in MiB) of memory set for the container.
final
name → String?
The name of the container.
final
networkBindings → List<NetworkBinding>?
The network bindings associated with the container.
final
networkInterfaces → List<NetworkInterface>?
The network interfaces associated with the container.
final
reason → String?
A short (255 max characters) human-readable string to provide additional details about a running or stopped container.
final
runtimeId → String?
The ID of the Docker container.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskArn → String?
The ARN of the task.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited