DescribeTaskDefinitionResponse class

Constructors

DescribeTaskDefinitionResponse({List<Tag>? tags, TaskDefinition? taskDefinition})
DescribeTaskDefinitionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
The metadata that is applied to the task definition to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define.
final
taskDefinition → TaskDefinition?
The full task definition description.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited