RegisterTaskDefinitionResponse class

Constructors

RegisterTaskDefinitionResponse({List<Tag>? tags, TaskDefinition? taskDefinition})
RegisterTaskDefinitionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
The list of tags associated with the task definition.
final
taskDefinition → TaskDefinition?
The full description of the registered task definition.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited