ServiceEvent class

Details on an event associated with a service.

Constructors

ServiceEvent({DateTime? createdAt, String? id, String? message})
ServiceEvent.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → DateTime?
The Unix timestamp for when the event was triggered.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The ID string of the event.
final
message → String?
The event message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited