TaskOverride class

The overrides associated with a task.

Constructors

TaskOverride({List<ContainerOverride>? containerOverrides, String? cpu, String? executionRoleArn, List<InferenceAcceleratorOverride>? inferenceAcceleratorOverrides, String? memory, String? taskRoleArn})
TaskOverride.fromJson(Map<String, dynamic> json)
factory

Properties

containerOverrides → List<ContainerOverride>?
One or more container overrides sent to a task.
final
cpu → String?
The cpu override for the task.
final
executionRoleArn → String?
The Amazon Resource Name (ARN) of the task execution IAM role override for the task.
final
hashCode → int
The hash code for this object.
no setterinherited
inferenceAcceleratorOverrides → List<InferenceAcceleratorOverride>?
The Elastic Inference accelerator override for the task.
final
memory → String?
The memory override for the task.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskRoleArn → String?
The Amazon Resource Name (ARN) of the IAM role that containers in this task can assume. All containers in this task are granted the permissions that are specified in this role.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited